@@ -118,8 +118,8 @@ class GeneratorTestCase(base.BaseTestCase):
         'opt_with_DeprecatedOpt': cfg.BoolOpt(
             'foo-bar',
             help='Opt with DeprecatedOpt',
-            deprecated_opts = [cfg.DeprecatedOpt('foo-bar',
-                                                 group='deprecated')]),
+            deprecated_opts=[cfg.DeprecatedOpt('foo-bar',
+                                               group='deprecated')]),
         # Unknown Opt default must be a string
         'unknown_type': cfg.Opt('unknown_opt',
                                 default='123',
@@ -811,6 +811,10 @@ class GeneratorTestCase(base.BaseTestCase):
 #
 
 # multiple strings (multi valued)
+#
+# This option has a sample default set, which means that
+# its actual default value may vary from the one documented
+# below.
 #multi_opt = 5
 #multi_opt = 6
 ''')),
@@ -1014,6 +1018,41 @@ class GeneratorTestCase(base.BaseTestCase):
             self.assertFalse(mock_log.warning.called)
 
 
+class GeneratorFileHandlingTestCase(base.BaseTestCase):
+
+    def setUp(self):
+        super(GeneratorFileHandlingTestCase, self).setUp()
+
+        self.conf = cfg.ConfigOpts()
+        self.config_fixture = config_fixture.Config(self.conf)
+        self.config = self.config_fixture.config
+
+    @mock.patch.object(generator, '_get_groups')
+    @mock.patch.object(generator, '_list_opts')
+    def test_close_generated_file(self, a, b):
+        generator.register_cli_opts(self.conf)
+        self.config(output_file='somefile')
+
+        m = mock.mock_open()
+        m.close = mock.Mock()
+
+        with mock.patch.object(generator, 'open', m, create=True):
+            generator.generate(self.conf, output_file=None)
+
+        m().close.assert_called_once()
+
+    @mock.patch.object(generator, '_get_groups')
+    @mock.patch.object(generator, '_list_opts')
+    def test_not_close_external_file(self, a, b):
+        generator.register_cli_opts(self.conf)
+        self.config()
+
+        m = mock.Mock()
+        generator.generate(self.conf, output_file=m)
+
+        m().close.assert_not_called()
+
+
 class DriverOptionTestCase(base.BaseTestCase):
 
     def setUp(self):
